from fa_purity.frozen import (
    freeze,
)
from fa_purity.json.factory import (
    from_any,
)
from fa_purity.json.value.core import (
    JsonValue,
)


def test_from_any() -> None:
    json_obj = freeze(
        {
            "foo": JsonValue(
                freeze(
                    {
                        "nested": JsonValue(
                            tuple([JsonValue("hi"), JsonValue(99)])
                        ),
                    }
                )
            )
        }
    )
    json_obj_from_raw = from_any({"foo": {"nested": ["hi", 99]}}).unwrap()
    assert json_obj == json_obj_from_raw



from .core import (
    Result,
    ResultE,
)
from fa_purity.frozen import (
    FrozenDict,
)
from typing import (
    TypeVar,
)

_K = TypeVar("_K")
_V = TypeVar("_V")


def try_get(data: FrozenDict[_K, _V], key: _K) -> ResultE[_V]:
    if key in data:
        return Result.success(data[key])
    return Result.failure(KeyError(key))
